@@ -28,6 +28,7 @@ from .helpers import datetime_str_from_timestamp
 from .helpers import get_service_account_token
 from .helpers import parse_datetime
 from .helpers import timestamp2datetime
+from .helpers import Lazy
 from .json import SafeJSONEncoder
 from .logging import init_logging
 from .openshift import OpenShift
@@ -35,7 +36,7 @@ from .workflows import Workflow
 from .workflows import WorkflowManager
 
 __name__ = "thoth-common"
-__version__ = "0.13.11"
+__version__ = "0.14.0"
 
 
 __all__ = [
@@ -55,4 +56,5 @@ __all__ = [
     "Workflow",
     "WorkflowManager",
     "timestamp2datetime",
+    "Lazy",
 ]
